@@ -225,8 +225,8 @@ Options:\n\
  -D, --new-datadir=NEWDATADIR    new cluster data directory\n\
  -b, --old-bindir=OLDBINDIR      old cluster executable directory\n\
  -B, --new-bindir=NEWBINDIR      new cluster executable directory\n\
- -p, --old-port=portnum          old cluster port number (default \"%d\")\n\
- -P, --new-port=portnum          new cluster port number (default \"%d\")\n\
+ -p, --old-port=portnum          old cluster port number (default %d)\n\
+ -P, --new-port=portnum          new cluster port number (default %d)\n\
  \n\
  -u, --user=username             clusters superuser (default \"%s\")\n\
  -c, --check                     check clusters only, don't change any data\n\
